@@ -15,6 +15,7 @@ import pytz
 from flask import Flask
 from invenio_db import db
 from invenio_records import Record
+from invenio_search.engine import check_os_version
 
 from invenio_indexer import InvenioIndexer
 from invenio_indexer.api import RecordIndexer
@@ -64,7 +65,6 @@ def test_hook_initialization(base_app):
         args = (app,)
         kwargs = dict(
             index=app.config["INDEXER_DEFAULT_INDEX"],
-            doc_type="_doc",
             arguments={},
             record=record,
             json={
@@ -80,7 +80,6 @@ def test_hook_initialization(base_app):
             version=0,
             version_type="force",
             index=app.config["INDEXER_DEFAULT_INDEX"],
-            doc_type="_doc",
             body={
                 "title": "Test",
                 "_created": pytz.utc.localize(record.created).isoformat(),
@@ -121,7 +120,6 @@ def test_index_prefixing(base_app):
                 version=0,
                 version_type="external_gte",
                 index="test-" + default_index,
-                doc_type="_doc",
                 body={
                     "title": "Test",
                     "_created": pytz.utc.localize(record.created).isoformat(),
@@ -137,7 +135,6 @@ def test_index_prefixing(base_app):
                 },
                 record=record,
                 index=default_index,  # non-prefixed index passed to receiver
-                doc_type="_doc",
                 arguments={},
             )
 
@@ -147,7 +144,6 @@ def test_index_prefixing(base_app):
                 version=0,
                 version_type="external_gte",
                 index="test-records-authorities-authority-v1.0.0",
-                doc_type="_doc",
                 body={
                     "$schema": "/records/authorities/authority-v1.0.0.json",
                     "title": "Test with schema",
@@ -165,14 +161,12 @@ def test_index_prefixing(base_app):
                 },
                 record=record2,
                 index="records-authorities-authority-v1.0.0",  # no prefix
-                doc_type="_doc",
                 arguments={},
             )
             RecordIndexer(search_client=client_mock).delete(record3)
             client_mock.delete.assert_called_with(
                 id=str(record3.id),
                 index="test-" + default_index,
-                doc_type="_doc",
                 version=record3.revision_id,
                 version_type="external_gte",
             )
